==> 1.0.119+1.tar.gz: lib/components/UikOrderProductCard.dart <==
import 'package:flutter/material.dart';
import 'package:ui_sdk/components/UikWidget.dart';
import 'package:ui_sdk/components/WidgetType.dart';
import 'package:ui_sdk/props/UikOrderProductCardProps.dart';
import 'package:ui_sdk/utils/UikActionListner.dart';

class UikOrderProductCard extends UikWidget {
  final WidgetType _widgetType;
  final UikOrderProductCardProps _uikOrderProductCardProps;

  UikOrderProductCard(this._widgetType, this._uikOrderProductCardProps)
      : super(_widgetType, _uikOrderProductCardProps);

  @override
  _UikOrderProductCardState createState() =>
      _UikOrderProductCardState(_uikOrderProductCardProps);
}

class _UikOrderProductCardState extends State<UikOrderProductCard> {
  final UikOrderProductCardProps _uikOrderProductCardProps;

  _UikOrderProductCardState(this._uikOrderProductCardProps);

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: () async {
        await executeUikWidgetAction(_uikOrderProductCardProps.action);
      },
      child: Container(
        padding: _uikOrderProductCardProps.enablePadding
            ? const EdgeInsets.all(10.0)
            : null,
        margin: EdgeInsets.only(
          top: _uikOrderProductCardProps.topMargin,
          bottom: _uikOrderProductCardProps.bottomMargin,
          left: _uikOrderProductCardProps.leftMargin,
          right: _uikOrderProductCardProps.rightMargin,
        ),
        decoration: BoxDecoration(
          color: (_uikOrderProductCardProps.opacity != null)
              ? _uikOrderProductCardProps.bgColor
                  .withOpacity(_uikOrderProductCardProps.opacity!)
              : _uikOrderProductCardProps.bgColor,
          borderRadius:
              BorderRadius.circular(_uikOrderProductCardProps.borderRadius),
        ),
        child: Column(
          mainAxisSize: MainAxisSize.min,
          mainAxisAlignment: MainAxisAlignment.start,
          crossAxisAlignment: CrossAxisAlignment.start,
          children: _uikOrderProductCardProps.widgetList,
        ),
      ),
    );
  }
}

==> 1.0.128+1.tar.gz: lib/components/UikOrderProductCard.dart <==
import 'package:flutter/material.dart';
import 'package:ui_sdk/components/UikWidget.dart';
import 'package:ui_sdk/components/WidgetType.dart';
import 'package:ui_sdk/props/UikOrderProductCardProps.dart';
import 'package:ui_sdk/utils/UikActionListner.dart';

class UikOrderProductCard extends UikWidget {
  final WidgetType _widgetType;
  final UikOrderProductCardProps _uikOrderProductCardProps;

  UikOrderProductCard(this._widgetType, this._uikOrderProductCardProps)
      : super(_widgetType, _uikOrderProductCardProps);

  @override
  _UikOrderProductCardState createState() =>
      _UikOrderProductCardState(_uikOrderProductCardProps);
}

class _UikOrderProductCardState extends State<UikOrderProductCard> {
  final UikOrderProductCardProps _uikOrderProductCardProps;

  _UikOrderProductCardState(this._uikOrderProductCardProps);

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: () async {
        await executeUikWidgetAction(_uikOrderProductCardProps.action,context);
      },
      child: Container(
        padding: _uikOrderProductCardProps.enablePadding
            ? const EdgeInsets.all(10.0)
            : null,
        margin: EdgeInsets.only(
          top: _uikOrderProductCardProps.topMargin,
          bottom: _uikOrderProductCardProps.bottomMargin,
          left: _uikOrderProductCardProps.leftMargin,
          right: _uikOrderProductCardProps.rightMargin,
        ),
        decoration: BoxDecoration(
          color: (_uikOrderProductCardProps.opacity != null)
              ? _uikOrderProductCardProps.bgColor
                  .withOpacity(_uikOrderProductCardProps.opacity!)
              : _uikOrderProductCardProps.bgColor,
          borderRadius:
              BorderRadius.circular(_uikOrderProductCardProps.borderRadius),
        ),
        child: Column(
          mainAxisSize: MainAxisSize.min,
          mainAxisAlignment: MainAxisAlignment.start,
          crossAxisAlignment: CrossAxisAlignment.start,
          children: _uikOrderProductCardProps.widgetList,
        ),
      ),
    );
  }
}
